==> xray_audit-1.2.0.tar.gz: xray_audit/src/Plugin/xray_audit/tasks/QueryGroup/XrayAuditQueryTaskVocabularyPlugin.php <==
<?php

namespace Drupal\xray_audit\Plugin\xray_audit\tasks\QueryGroup;

use Drupal\taxonomy\Entity\Vocabulary;

/**
 * Plugin implementation of queries_data_node.
 *
 * @XrayAuditTaskPlugin (
 *   id = "queries_data_vocabulary",
 *   label = @Translation("Vocabularies reports"),
 *   description = @Translation("Reports on the vocabularies (taxonomies) of this site."),
 *   group = "queries_data",
 *   sort = 3,
 *   operations = {
 *      "vocabulary_description" = {
 *          "label" = "Vocabularies",
 *          "description" = "Sites's vocabulary."
 *       },
 *       "vocabulary_count" = {
 *          "label" = "Vocabulary count",
 *          "description" = "List vocabularies and their respective counts."
 *       },
 *      "vocabulary_count_per_language" = {
 *          "label" = "Vocabulary count per language",
 *          "description" = "List vocabularies and their respective counts per lenguage."

 *       }
 *    },
 *   dependencies = {"taxonomy"}
 *
 * )
 */
class XrayAuditQueryTaskVocabularyPlugin extends XrayAuditQueryTaskPluginBase {

  /**
   * {@inheritdoc}
   */
  public function getDataOperationResult(string $operation = NULL) {
    switch ($operation) {
      case 'vocabulary_description':
        return $this->vocabulariesDescription();

      case 'vocabulary_count':
        return $this->vocabulariesCount();

      case 'vocabulary_count_per_language':
        return $this->vocabulariesCountPerLanguage();
    }
    return [];
  }

  /**
   * Vocabularies description.
   *
   * @return array
   *   Render array.
   */
  public function vocabulariesDescription() {
    $headerTable = [
      $this->t('Id'),
      $this->t('Label'),
      $this->t('Description'),
      $this->t('Langcode'),
    ];
    $resultTable = [];
    $vocabularies = Vocabulary::loadMultiple();
    foreach ($vocabularies as $key => $vocabulary) {
      $resultTable[] = [
        $key,
        $vocabulary->label(),
        $vocabulary->get('description'),
        $vocabulary->get('langcode'),
      ];
    }
    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];
  }

  /**
   * Vocabularies count.
   *
   * @return array
   *   Render array.
   */
  public function vocabulariesCount() {
    $headerTable = [
      $this->t('Vid'),
      $this->t('Count'),
      $this->t('Language'),
    ];
    $resultTable = [];
    $alias = 'count';

    $language_by_default = $this->languageManager->getDefaultLanguage()->getId();

    $storage = $this->entityTypeManager->getStorage('taxonomy_term');
    $result = $storage
      ->getAggregateQuery()
      ->accessCheck(FALSE)
      ->groupBy('vid')
      ->aggregate('tid', 'COUNT', $language_by_default, $alias)
      ->execute();
    foreach ($result as $row) {
      if (empty($row['vid'])) {
        continue;
      }
      $resultTable[] = [$row['vid'], $row['count'], $language_by_default];
    }
    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];
  }

  /**
   * Vocabularies count per language.
   *
   * @return array
   *   Render array.
   */
  public function vocabulariesCountPerLanguage() {
    $headerTable = [
      $this->t('Vid'),
      $this->t('Langcode'),
      $this->t('Count'),
    ];
    $resultTable = [];
    $alias = 'count';

    $storage = $this->entityTypeManager->getStorage('taxonomy_term');
    $result = $storage
      ->getAggregateQuery()
      ->accessCheck(FALSE)
      ->groupBy('vid')
      ->groupBy('langcode')
      ->aggregate('tid', 'COUNT', NULL, $alias)
      ->execute();
    foreach ($result as $row) {
      $resultTable[] = [$row['vid'], $row['langcode'], $row['count']];
    }
    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];
  }

}

==> xray_audit-1.5.1.tar.gz: xray_audit/src/Plugin/xray_audit/tasks/QueryGroup/XrayAuditQueryTaskVocabularyPlugin.php <==
<?php

namespace Drupal\xray_audit\Plugin\xray_audit\tasks\QueryGroup;

use Drupal\taxonomy\Entity\Vocabulary;

/**
 * Plugin implementation of queries_data_node.
 *
 * @XrayAuditTaskPlugin (
 *   id = "queries_data_vocabulary",
 *   label = @Translation("Vocabularies reports"),
 *   description = @Translation("Reports on the vocabularies (taxonomies) of this site."),
 *   group = "queries_data",
 *   sort = 3,
 *   operations = {
 *      "vocabulary_description" = {
 *          "label" = "Vocabularies",
 *          "description" = "Sites's vocabulary."
 *       },
 *       "vocabulary_count" = {
 *          "label" = "Vocabulary count",
 *          "description" = "List vocabularies and their respective counts."
 *       },
 *      "vocabulary_count_per_language" = {
 *          "label" = "Vocabulary count per language",
 *          "description" = "List vocabularies and their respective counts
 *            per lenguage."
 *       }
 *    },
 *   dependencies = {"taxonomy"}
 *
 * )
 */
class XrayAuditQueryTaskVocabularyPlugin extends XrayAuditQueryTaskPluginBase {

  /**
   * {@inheritdoc}
   */
  public function getDataOperationResult(string $operation = NULL) {
    switch ($operation) {
      case 'vocabulary_description':
        return $this->vocabulariesDescription();

      case 'vocabulary_count':
        return $this->vocabulariesCount();

      case 'vocabulary_count_per_language':
        return $this->vocabulariesCountPerLanguage();
    }
    return [];
  }

  /**
   * Vocabularies description.
   *
   * @return array
   *   Render array.
   */
  public function vocabulariesDescription() {
    $headerTable = [
      $this->t('Id'),
      $this->t('Label'),
      $this->t('Description'),
      $this->t('Langcode'),
    ];
    $resultTable = [];
    $vocabularies = Vocabulary::loadMultiple();
    foreach ($vocabularies as $key => $vocabulary) {
      $resultTable[] = [
        $key,
        $vocabulary->label(),
        $vocabulary->get('description'),
        $vocabulary->get('langcode'),
      ];
    }
    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];
  }

  /**
   * Vocabularies count.
   *
   * @return array
   *   Render array.
   */
  public function vocabulariesCount() {
    $headerTable = [
      $this->t('Vid'),
      $this->t('Count'),
      $this->t('Language'),
    ];
    $resultTable = [];
    $alias = 'count';

    $language_by_default = $this->languageManager->getDefaultLanguage()->getId();

    $storage = $this->entityTypeManager->getStorage('taxonomy_term');
    $result = $storage
      ->getAggregateQuery()
      ->accessCheck(FALSE)
      ->groupBy('vid')
      ->aggregate('tid', 'COUNT', $language_by_default, $alias)
      ->execute();
    foreach ($result as $row) {
      if (empty($row['vid'])) {
        continue;
      }
      $resultTable[] = [$row['vid'], $row['count'], $language_by_default];
    }
    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];
  }

  /**
   * Vocabularies count per language.
   *
   * @return array
   *   Render array.
   */
  public function vocabulariesCountPerLanguage() {
    $headerTable = [
      $this->t('Vid'),
      $this->t('Langcode'),
      $this->t('Count'),
    ];
    $resultTable = [];
    $alias = 'count';

    $storage = $this->entityTypeManager->getStorage('taxonomy_term');
    $result = $storage
      ->getAggregateQuery()
      ->accessCheck(FALSE)
      ->groupBy('vid')
      ->groupBy('langcode')
      ->aggregate('tid', 'COUNT', NULL, $alias)
      ->execute();
    foreach ($result as $row) {
      $resultTable[] = [$row['vid'], $row['langcode'], $row['count']];
    }
    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];
  }

}
